#ifndef NT2_INCLUDE_FUNCTIONS_QUAD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_QUAD_HPP_INCLUDED

#include <nt2/integration/include/functions/quad.hpp>

#endif
